@@ -6,9 +6,13 @@ from typing import Optional
 from pydantic import BaseModel, Field
 
 from flask_openapi3 import APIView
-from flask_openapi3 import OpenAPI, Tag, Info, HTTPBearer
+from flask_openapi3 import OpenAPI, Tag, Info
 
-jwt = HTTPBearer()
+jwt = {
+    "type": "http",
+    "scheme": "bearer",
+    "bearerFormat": "JWT"
+}
 security_schemes = {"jwt": jwt}
 info = Info(title='book API', version='1.0.0')
 app = OpenAPI(__name__, info=info, security_schemes=security_schemes)
@@ -38,12 +42,12 @@ class BookListAPIView:
     @api_view.doc(summary="get book list")
     def get(self, query: BookQuery):
         print(self.a)
-        return query.json()
+        return query.model_dump_json()
 
     @api_view.doc(summary="create book")
     def post(self, body: BookBody):
-        """description for create book"""
-        return body.json()
+        """description for a created book"""
+        return body.model_dump_json()
 
 
 @api_view.route("/book/<id>")
